@@ -251,13 +251,15 @@ void Fl_Tree_set_callback_reason(Fl_Tree *self, int reason);
 
 int Fl_Tree_callback_reason(const Fl_Tree *self);
 
-int Fl_Tree_item_pathname(const Fl_Tree *self, char *pathname, int pathnamelen, const Fl_Tree_Item *item);
+int Fl_Tree_item_pathname(const Fl_Tree *self, char *pathname, int pathnamelen,
+                          const Fl_Tree_Item *item);
 
 /* TreeItems */
 
 Fl_Tree_Item *Fl_Tree_Item_new(Fl_Tree *tree, const char *txt);
 
-void Fl_Tree_Item_draw_item_content(Fl_Tree_Item *item, int (*cb)(Fl_Tree_Item *self, int, void *), void *data);
+void Fl_Tree_Item_draw_item_content(Fl_Tree_Item *item, int (*cb)(Fl_Tree_Item *self, int, void *),
+                                    void *data);
 
 int Fl_Tree_Item_x(const Fl_Tree_Item *self);
 
